#!/usr/bin/python3

import argparse
import subprocess
import sys
import traceback

NAG_OK = 0
NAG_WARNING = 1
NAG_CRITICAL = 2
NAG_UNKNOWN = 3

def setup_parser():
    parser = argparse.ArgumentParser(prog='check_apcaccess')

    parser.add_argument('--host', '-H', default='localhost', help='hostname')

    parser.add_argument('--port', '-p', default=3551, type=int, help='port')

    parser.add_argument('-c', type=float, help='critical value')

    parser.add_argument('-w', type=float, help='warn level')

    parser.add_argument('--field', help='which field of the output of apcaccess should be checked', required=True)

    parser.add_argument('-v', action='store_true', default=False, help='verbose to stdout')

    return parser


if __name__=='__main__':

    try: 
        parser = setup_parser()
        args=parser.parse_args()

        p=subprocess.Popen(["/usr/sbin/apcaccess", "-h" f"{args.host}:{args.port}"], stdout=subprocess.PIPE)
        apcaccess_output=p.stdout.read().decode()

        if args.v:
            print(apcaccess_output, sys.stderr)

        data = {}
        for line in apcaccess_output.splitlines():
            field, value = line.split(':',1)
            field = field.strip()
            value = value.strip()

            data[field] = value

        if args.v:
            print(data, sys.stderr)

        if args.field is not None and args.field not in data:
            print(f'UNKNOWN - filed {args.field} not found in fileds provided by apcaccess, i.e. {tuple(data.keys())}')
            sys.exit(NAG_UNKNOWN)
        else:
            assert(args.c is not None)
            assert(args.w is not None)
            assert(args.c < args.w)

            tup = data[args.field].split(" ")

            nominal_value = float(tup[0])
            if len(tup) == 2:
                unit = f" {tup[1]}"
            else:
                unit = ""
               
            perf_data = f"'{args.field}'={nominal_value};{args.w};{args.c}'"

            if args.c > nominal_value:
                print(f'CRITICAL - {args.field}: {nominal_value}<{args.c}{unit}|{perf_data}')
                sys.exit(NAG_CRITICAL)

            if args.w > nominal_value:
                print(f'WARNING - {args.field}: {nominal_value}<{args.w}{unit}|{perf_data}')
                sys.exit(NAG_WARNING)

            print(f'OK - {args.field}={nominal_value}{unit}|{perf_data}')
            sys.exit(NAG_OK)



    except Exception as e:
        print(f'UNKNOWN - {traceback.format_exc()}')
        import pprint
        pprint.pprint(locals())
        sys.exit(NAG_UNKNOWN)
        
        

        




    
                    


